import { ZERO } from '@/constants/common';
import { HALF } from '@/constants/dividers';
import { FEATURE_TYPE } from '@/constants/features';
import { Marker } from '@/redux/markers/markers.types';
import { BioEntity } from '@/types/models';
import { UsePointToProjectionResult } from '@/utils/map/usePointToProjection';
import isUUID from 'is-uuid';
import { Feature } from 'ol';
import { Point } from 'ol/geom';

export const getPinFeature = (
  { x, y, width, height, id }: Pick<BioEntity, 'id' | 'width' | 'height' | 'x' | 'y'> | Marker,
  pointToProjection: UsePointToProjectionResult,
): Feature => {
  const isMarker = isUUID.anyNonNil(`${id}`);

  const point = {
    x: x + (width || ZERO) / HALF,
    y: y + (height || ZERO) / HALF,
  };

  const feature = new Feature({
    geometry: new Point(pointToProjection(point)),
    id,
    type: isMarker ? FEATURE_TYPE.PIN_ICON_MARKER : FEATURE_TYPE.PIN_ICON_BIOENTITY,
  });

  return feature;
};
